@@ -5,7 +5,7 @@
  * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
  * Package: TMVA                                                                  *
  * Class  : PDF                                                                   *
- * Web    : http://tmva.sourceforge.net                                           *
+ *                                             *
  *                                                                                *
  * Description:                                                                   *
  *      Implementation (see header for description)                               *
@@ -27,7 +27,7 @@
  *                                                                                *
  * Redistribution and use in source and binary forms, with or without             *
  * modification, are permitted according to the terms listed in LICENSE           *
- * (http://tmva.sourceforge.net/LICENSE)                                          *
+ * (see tmva/doc/LICENSE)                                          *
  **********************************************************************************/
 
 /*! \class TMVA::PDF
@@ -339,24 +339,24 @@ void TMVA::PDF::BuildSplinePDF()
       break;
 
    case kSpline1:
-      fSpline = new TMVA::TSpline1( "spline1", new TGraph(*fGraph) );
+      fSpline = new TMVA::TSpline1( "spline1", fGraph );
       break;
 
    case kSpline2:
-      fSpline = new TMVA::TSpline2( "spline2", new TGraph(*fGraph) );
+      fSpline = new TMVA::TSpline2( "spline2", fGraph );
       break;
 
    case kSpline3:
-      fSpline = new TSpline3( "spline3", new TGraph(*fGraph) );
+      fSpline = new TSpline3( "spline3", fGraph );
       break;
 
    case kSpline5:
-      fSpline = new TSpline5( "spline5", new TGraph(*fGraph) );
+      fSpline = new TSpline5( "spline5", fGraph );
       break;
 
    default:
       Log() << kWARNING << "No valid interpolation method given! Use Spline2" << Endl;
-      fSpline = new TMVA::TSpline2( "spline2", new TGraph(*fGraph) );
+      fSpline = new TMVA::TSpline2( "spline2", fGraph );
       Log() << kFATAL << " Well.. .thinking about it, I better quit so you notice you are forced to fix the mistake " << Endl;
       std::exit(1);
    }
